@@ -6,6 +6,8 @@ dup2 fileno(STDERR), fileno(STDOUT);
 use strict;
 use warnings;
 use Benchmark ':all';
+use sealed 'verify';
+
 our ($x, $z);
 $x = bless {}, "Foo";
 $z = Foo->can("foo");
@@ -13,15 +15,14 @@ sub method {$x->foo}
 sub class  {Foo->foo}
 sub anon   {$z->($x)}
 sub bar { 2 }
-sub reentrant;
+
 BEGIN {
   package Foo;
   use base 'sealed';
-  use sealed 'deparse';
   sub foo { shift }
   sub bar    { 1 }
   my $n;
-  sub _foo :Sealed (main $x) { $n++ ? $x->bar : $x->reentrant }
+  sub _foo :Sealed { my main $x = shift; $n++ ? $x->bar : $x->reentrant }
 }
 sub func   {Foo::foo($x)}
 
@@ -33,13 +34,11 @@ sub sealed :Sealed {
     $y->foo();
   }
 
-use sealed 'verify';
-sub also_sealed;
 sub also_sealed :Sealed (__PACKAGE__ $a, Int $b, Str $c="HOLA", Int $d//=3, Int $e||=4) {
     if ($a) {
         my Benchmark $bench;
         my $inner = $a;
-        return sub :Sealed {
+        return sub :Sealed (__PACKAGE__ $z) {
             my Foo $b = $a;
             $inner->foo($b->bar($inner->bar, $inner, $bench->new));
             $a = $inner;
@@ -50,8 +49,7 @@ sub also_sealed :Sealed (__PACKAGE__ $a, Int $b, Str $c="HOLA", Int $d//=3, Int
     $a->bar();
 }
 
-use sealed;
-sub reentrant :Sealed (__PACKAGE__ $b) { local our @Q=1; my $c = $b->_foo }
+sub reentrant :Sealed { my main $b = shift; local our @Q=1; my $c = $b->_foo; }
 
 ok(bless({})->reentrant()==2);
 
@@ -70,7 +68,7 @@ ok(1);
 use constant LOOPS => 3;
 
 sub method2 {
-  my $obj = bless {};
+  my $obj = "main";
   for (1..LOOPS) {
     $obj->foo;
     $obj->bar;
@@ -79,7 +77,7 @@ sub method2 {
 }
 
 sub sealed2 :Sealed {
-  my main $obj = bless {}; # sealed-src-filter
+  my main $obj; # sealed-src-filter
   for (1..LOOPS) {
     $obj->foo;
     $obj->bar;
@@ -94,6 +92,6 @@ cmpthese 1_000_000, {
 
 ok(1);
 
-eval {also_sealed($x,-1)->()};
+eval {also_sealed($x,-1)->($x)};
 warn $@;
 ok (length($@) > 0);
